@@ -3,7 +3,6 @@ use std::time::SystemTime;
 
 use voltdb_client_rust::*;
 
-
 fn main() -> Result<(), VoltError> {
     #[derive(Debug)]
     struct Test {
@@ -33,8 +32,11 @@ fn main() -> Result<(), VoltError> {
             }
         }
     }
-    // Creates new `Node`.
-    let mut node = get_node("localhost:21211")?;
+
+    let hosts = vec![IpPort::new("localhost".to_string(), 21211)];
+    let mut pool = Pool::new(Opts::new(hosts)).unwrap();
+
+    let mut node = pool.get_conn()?;
     // Create table if not exists.
     let has_table_check = block_for_result(&node.query("select t1 from test_types limit 1")?);
     match has_table_check {
@@ -71,10 +73,11 @@ fn main() -> Result<(), VoltError> {
     }
     let bs = vec![1 as u8, 2, 3, 4];
     let time = DateTime::from(SystemTime::now());
+    let none_i16: Option<i16> = Option::None;
 
 
     // call sp with marco `volt_parma!` , test_types.insert is crated with table.
-    let mut table = block_for_result(&node.call_sp("test_types.insert", volt_param![1,2,3,4,5,6,"7",bs,time])?)?;
+    let mut table = block_for_result(&node.call_sp("test_types.insert", volt_param![1,none_i16,3,4,5,6,"7",bs,time])?)?;
     while table.advance_row() {
         println!("{}", table.debug_row());
     }
@@ -132,20 +135,19 @@ fn main() -> Result<(), VoltError> {
     }
 
 
+
+    let null_i16: Option<i16> = Option::None;
     let header = vec!["T1", "T2", "T3", "T4", "T5", "T6", "T7", "T8", "T9"];
     let tp = vec![TINYINT_COLUMN, SHORT_COLUMN, INT_COLUMN, LONG_COLUMN, FLOAT_COLUMN, DECIMAL_COLUMN, STRING_COLUMN, VAR_BIN_COLUMN, TIMESTAMP_COLUMN];
     let header: Vec<String> = header.iter().map(|f| f.to_string()).collect::<Vec<String>>();
     let mut table = VoltTable::new_table(tp, header);
     let decimal = BigDecimal::from(16);
-    let data = volt_param! {true, 32767 as i16 , 2147483647 as i32,  9223372036854775807 as i64 ,  15.0, decimal  , "17",bs, time   };
+    let data = volt_param! {true, null_i16 , 2147483647 as i32,  9223372036854775807 as i64 ,  15.0, decimal  , "17",bs, time   };
     table.add_row(data)?;
     // call proc with volt table
     let mut res = block_for_result(&node.call_sp("ApplicationCreate", volt_param![table])?)?;
     while res.advance_row() {
         println!("{:?}", res.debug_row());
     }
-    node.shutdown()?;
-
-
     Ok({})
 }
